==> ikaaro-0.50.5.tar.gz: ikaaro-0.50.5/ui/tiny_mce/themes/advanced/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advanced_dlg',{
about_title:"TinyMCE\u306B\u3064\u3044\u3066",
about_general:"\u8A73\u7D30",
about_help:"\u30D8\u30EB\u30D7",
about_license:"\u30E9\u30A4\u30BB\u30F3\u30B9",
about_plugins:"\u30D7\u30E9\u30B0\u30A4\u30F3",
about_plugin:"\u30D7\u30E9\u30B0\u30A4\u30F3",
about_author:"\u4F5C\u8005",
about_version:"\u30D0\u30FC\u30B8\u30E7\u30F3",
about_loaded:"\u8AAD\u8FBC\u6E08\u307F\u30D7\u30E9\u30B0\u30A4\u30F3",
anchor_title:"\u30A2\u30F3\u30AB\u30FC\u306E\u633F\u5165/\u7DE8\u96C6",
anchor_name:"\u30A2\u30F3\u30AB\u30FC\u540D",
code_title:"HTML\u30BD\u30FC\u30B9\u30A8\u30C7\u30A3\u30BF",
code_wordwrap:"\u6298\u308A\u8FD4\u3057",
colorpicker_title:"\u8272\u306E\u9078\u629E",
colorpicker_picker_tab:"\u30AB\u30E9\u30FC\u30D4\u30C3\u30AB\u30FC",
colorpicker_picker_title:"\u30AB\u30E9\u30FC\u30D4\u30C3\u30AB\u30FC",
colorpicker_palette_tab:"\u30D1\u30EC\u30C3\u30C8",
colorpicker_palette_title:"\u30D1\u30EC\u30C3\u30C8",
colorpicker_named_tab:"\u65E2\u5B9A\u8272",
colorpicker_named_title:"\u65E2\u5B9A\u8272",
colorpicker_color:"\u30AB\u30E9\u30FC:",
colorpicker_name:"\u540D\u524D:",
charmap_title:"\u7279\u6B8A\u6587\u5B57",
image_title:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
image_src:"\u753B\u50CFURL",
image_alt:"\u753B\u50CF\u306E\u8AAC\u660E",
image_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
image_border:"\u67A0\u7DDA",
image_dimensions:"\u30B5\u30A4\u30BA",
image_vspace:"\u4E0A\u4E0B\u4F59\u767D",
image_hspace:"\u5DE6\u53F3\u4F59\u767D",
image_align:"\u914D\u7F6E",
image_align_baseline:"Baseline",
image_align_top:"Top",
image_align_middle:"Middle",
image_align_bottom:"Bottom",
image_align_texttop:"Text top",
image_align_textbottom:"Text bottom",
image_align_left:"Left",
image_align_right:"Right",
link_title:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
link_url:"\u30EA\u30F3\u30AFURL",
link_target:"\u30BF\u30FC\u30B2\u30C3\u30C8",
link_target_same:"\u540C\u3058\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
link_target_blank:"\u65B0\u3057\u3044\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
link_titlefield:"\u30BF\u30A4\u30C8\u30EB",
link_is_email:"\u30E1\u30FC\u30EB\u30A2\u30C9\u30EC\u30B9\u304C\u5165\u529B\u3055\u308C\u307E\u3057\u305F\u3002\u30EA\u30F3\u30AF\u306Bmailto:\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
link_is_external:"\u30EA\u30F3\u30AF\u306Bhttp://\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
link_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/themes/advanced/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advanced_dlg',{
about_title:"TinyMCE\u306B\u3064\u3044\u3066",
about_general:"\u8A73\u7D30",
about_help:"\u30D8\u30EB\u30D7",
about_license:"\u30E9\u30A4\u30BB\u30F3\u30B9",
about_plugins:"\u30D7\u30E9\u30B0\u30A4\u30F3",
about_plugin:"\u30D7\u30E9\u30B0\u30A4\u30F3",
about_author:"\u4F5C\u8005",
about_version:"\u30D0\u30FC\u30B8\u30E7\u30F3",
about_loaded:"\u8AAD\u8FBC\u6E08\u307F\u30D7\u30E9\u30B0\u30A4\u30F3",
anchor_title:"\u30A2\u30F3\u30AB\u30FC\u306E\u633F\u5165/\u7DE8\u96C6",
anchor_name:"\u30A2\u30F3\u30AB\u30FC\u540D",
code_title:"HTML\u30BD\u30FC\u30B9\u30A8\u30C7\u30A3\u30BF",
code_wordwrap:"\u6298\u308A\u8FD4\u3057",
colorpicker_title:"\u8272\u306E\u9078\u629E",
colorpicker_picker_tab:"\u30AB\u30E9\u30FC\u30D4\u30C3\u30AB\u30FC",
colorpicker_picker_title:"\u30AB\u30E9\u30FC\u30D4\u30C3\u30AB\u30FC",
colorpicker_palette_tab:"\u30D1\u30EC\u30C3\u30C8",
colorpicker_palette_title:"\u30D1\u30EC\u30C3\u30C8",
colorpicker_named_tab:"\u65E2\u5B9A\u8272",
colorpicker_named_title:"\u65E2\u5B9A\u8272",
colorpicker_color:"\u30AB\u30E9\u30FC:",
colorpicker_name:"\u540D\u524D:",
charmap_title:"\u7279\u6B8A\u6587\u5B57",
image_title:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
image_src:"\u753B\u50CFURL",
image_alt:"\u753B\u50CF\u306E\u8AAC\u660E",
image_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
image_border:"\u67A0\u7DDA",
image_dimensions:"\u30B5\u30A4\u30BA",
image_vspace:"\u4E0A\u4E0B\u4F59\u767D",
image_hspace:"\u5DE6\u53F3\u4F59\u767D",
image_align:"\u914D\u7F6E",
image_align_baseline:"Baseline",
image_align_top:"Top",
image_align_middle:"Middle",
image_align_bottom:"Bottom",
image_align_texttop:"Text top",
image_align_textbottom:"Text bottom",
image_align_left:"Left",
image_align_right:"Right",
link_title:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
link_url:"\u30EA\u30F3\u30AFURL",
link_target:"\u30BF\u30FC\u30B2\u30C3\u30C8",
link_target_same:"\u540C\u3058\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
link_target_blank:"\u65B0\u3057\u3044\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
link_titlefield:"title\u5C5E\u6027",
link_is_email:"\u30E1\u30FC\u30EB\u30A2\u30C9\u30EC\u30B9\u304C\u5165\u529B\u3055\u308C\u307E\u3057\u305F\u3002\u30EA\u30F3\u30AF\u306Bmailto:\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
link_is_external:"\u30EA\u30F3\u30AF\u306Bhttp://\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
link_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});
